# IcomCommander

Serialized CI-V command executor with priority queuing (wfview-style).
Most users should use the high-level **Radio** API (via [`create_radio`](public-api-surface.md)), which
manages an `IcomCommander` internally.

::: icom_lan.commander.IcomCommander

## Priority Levels

::: icom_lan.commander.Priority
